% Clear all variables

close all
clear all
clc

%% Simulation variables
global a1 a2

CaseExample = 2; % Case i) IC1
% CaseExample = 2; % Case ii) IC2

switch CaseExample
    case 1
        % Case i) IC1
        a1 = 6;
        a2 = 6;
    case 2
        % Case ii) IC2
        a1 = sym(11/2);
        a2 = sym(61/11);
end

syms t x1(t) x2(t) real;
syms t positive

x = [x1;x2];

%% Initial Conditions

switch CaseExample
    case 1
        % Case i) IC1
        X0 = sym([1;1]);
    case 2
        % Case ii) IC2
        X0 = sym([1/2;6/11]);
end

% simulation horizon
tmax = 10; 
jmax = 110;

% rule for jumps
% rule = 1 -> priority for jumps
% rule = 2 -> priority for flows
rule = 1;

%% Perform Symbolic Simulation
TSPAN=[0 tmax];
JSPAN = [0 jmax];
vpaPr = 64; % vpa Variable precision arithmetic 

[tsymb jsymb xsymb] = HyEQSimbolicSolver(@fpr,@gpr,@Cpr,@Dpr,X0,TSPAN,JSPAN,x,t,rule,vpaPr);

%% Transform solutions to numeric hybrid time domain
maxt = (tsymb(end,2));
mint = (tsymb(1,1));
deltat = tmax; % Number of points to be evaluated in the symbolic function
tvec = eval([mint:abs(maxt-mint)/deltat:maxt]);

[t_htd j_htd x_htd] = symhtd2htd(tsymb,jsymb,xsymb,tvec);

%% Ploting solutions
close all
figure(1)
subplot(121);plotHarc(t_htd,j_htd,x_htd);
title('Symbolic simulation ([x_1,x_2] Vs (t,j))')
xlabel('time')
ylabel('x')
figure(2)
subplot(121);plotHarc(x_htd(:,1),j_htd,x_htd(:,2));
title('Symbolic simulation (x_1 Vs x_2)')
xlabel('x_1')
ylabel('x_2')

%% test2 numeric Simulator HyEQ (precision symbolic semantic, vs floating
% point semantic)

clearvars -except X0 a1 a2 vpaPr tmax jmax
a1 = double(a1);
a2 = double(a2);

clc

%% Initial Conditions for floating point simulator
X0 = double(vpa(X0,vpaPr));
% simulation horizon

% rule for jumps
% rule = 1 -> priority for jumps
% rule = 2 -> priority for flows
rule = 1;

%% Perform Numeric Simulation
TSPAN=[0 tmax];
JSPAN = [0 jmax];
options = odeset('RelTol',1e-16,'MaxStep',.1);

[t_htd,j_htd,x_htd] = HyEQsolver(@fpr,@gpr,@CprNum,@DprNum,...
    X0,TSPAN,JSPAN,rule,options);
%% Ploting solutions
figure(1)
subplot(122);plotHarc(t_htd,j_htd,x_htd);
title('Numeric simulation ([x_1,x_2] Vs (t,j))')
xlabel('time')
ylabel('x')
figure(2)
subplot(122);plotHarc(x_htd(:,1),j_htd,x_htd(:,2));
title('Numeric simulation (x_1 Vs x_2)')
xlabel('x_1')
ylabel('x_2')




