function [t_htd j_htd x_htd] = symhtd2htd(t,j,x,tvec,vpaPrin)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Matlab M-file       Project: HyEQ Toolbox  @ Hybrid Dynamics and Control
% Lab, http://www.u.arizona.edu/~sricardo/index.php?n=Main.Software
%
% Filename: isinSet.m
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Given a symbolic hybrid time domain and a time vector target generate the
% discrete hybrid time domain and the state vectors to be ploted afterward
% using  plotHybridArc
% t_htd: time vector
% j_htd: jump vector
% x_htd: state vector (double)
% t: symbolic time matrix
% j: jump vector
% x: state vector (symbolic function)
% tvec: target time vector (desired time vector)

%% Check inputs
if ~exist('vpaPrin','var')
    vpaPr = 50; % Default value
else
    vpaPr = vpaPrin;
end
if ~exist('tvec','var')
    maxt = vpa(t(end,2),vpaPr);
    mint = vpa(t(1,1),vpaPr);
else
    maxt = max(tvec);
    mint = min(tvec);
end
if isinf(abs(maxt)) || isinf(abs(mint)) || isnan(maxt) || isnan(mint)
    error('one or both of the plotting borders is/are either infinity or NAN')
end
% Check the target time vector
if maxt~=vpa(t(end,2),vpaPr) || mint~=vpa(t(1,1),vpaPr)
    warning('target vector does not fit the symbolic expressions, the output might be cropped.')
    [maxt imax] = min([eval(t(end,2)),maxt]);
    [mint imin] = max([eval(t(1,1)),mint]);
    newtvec = tvec(find(tvec<=mint,1,'last'):find(tvec>=maxt,1,'first'));
    newtvec(1) = mint;
    newtvec(end) = maxt;
    tvec = newtvec;
    if imin == 2
        init = find(eval(t(:,1))<= mint,1,'last');
    else
        init = 1;
    end
    if imax == 2
        endt = find(eval(t(:,2))>= maxt,1,'first');
    else
        endt = length(t);
    end
else
    init = 1;
    endt = length(t);
end



%% Create new vectors
thtd = sym([]);
jhtd = [];
xhtd = sym([]);
xfun = sym([]);

syms txsym


% HTD for symbolic htd and symbolic states vector
for it=init:endt
    if t(it,1)~=t(it,2) % if it is an non zero interval
        thtd(end+1:end+2) = (t(it,:).');
        jhtd(end+1:end+2) = j(it);
        xhtd(end+1,:) = x{it}(thtd(end-1));
        xhtd(end+1,:) = x{it}(thtd(end));
        xfun(end+1,:) = x{it}(txsym);
        xfun(end+1,:) = x{it}(txsym);
    else % if it is a zero measurement interval
        thtd(end+1) = (t(it,1));
        jhtd(end+1) = j(it);
        xhtd(end+1,:) = x{it}(thtd(end));
        xfun(end+1,:) = x{it}(txsym);
    end
end

% HTD for the target time vector
for it=vpa(tvec,vpaPr)
    if sum(thtd==it)==0 % the time instant does not belong to thtd
        igtit = find(thtd>it,1,'first'); % insert the element behind the first largest
        if ~isempty(igtit)
            thtd = cat(2,thtd(1:igtit-1),it,thtd(igtit:end));
            jhtd = cat(2,jhtd(1:igtit-1),jhtd(igtit),jhtd(igtit:end));
            txsym = it;
            xhtd = cat(1,xhtd(1:igtit-1,:),subs(xfun(igtit-1,:)),xhtd(igtit:end,:));
            xfun = cat(1,xfun(1:igtit-1,:),(xfun(igtit-1,:)),xfun(igtit:end,:));
        end
    end
end

%% Cut the first and/or and last value of the vectors if needed
if maxt~=vpa(t(end,2),vpaPr) || mint~=vpa(t(1,1),vpaPr)
    if imin == 2
        t_htd = double(thtd(2:end));
        j_htd = double(jhtd(2:end));
        x_htd = double(xhtd(2:end,:));
    else
        t_htd = double(thtd);
        j_htd = double(jhtd);
        x_htd = double(xhtd);
    end
    if imax == 2
        t_htd = (t_htd(1:end-1));
        j_htd = (j_htd(1:end-1));
        x_htd = (x_htd(1:end-1,:));
    else
        t_htd = (t_htd);
        j_htd = (j_htd);
        x_htd = (x_htd);
    end
else
    t_htd = double(thtd);
    j_htd = double(jhtd);
    x_htd = double(xhtd);    
end













