% Clear all variables

clear all
close all
clc

%% Simulation variables

syms t x1(t) x2(t) real;
syms t positive

x = [x1;x2];
global gamma
gamma = -9.81;

%% Simulation Horizon

% rule for jumps
% rule = 1 -> priority for jumps
% rule = 2 -> priority for flows
rule = 1;
tmax = 400; %400;
jmax = 400; %400;

%% Perform Symbolic Simulation
TSPAN=[0 tmax];
JSPAN = [0 jmax];

% Initial Conditions
x1_0 = (981*sym(pi)^2)/200;
x0 = [x1_0;0];
vpaPr = 132; % vpa Variable precision arithmetic 

[tsymb jsymb xsymb] = HyEQSimbolicSolver(@fBB,@gBB,@CBB,@DBB,x0,TSPAN,JSPAN,x,t,rule,vpaPr);

%% Perform Numeric Simulation
TSPAN=[0 tmax];
JSPAN = [0 jmax];
x1_0 = (981*(pi)^2)/200;
x0 = [x1_0;0];
options = odeset('RelTol',1e-26,'MaxStep',.01);

[tnum jnum xnum] = HyEQsolver(@fBB,@gBB,@CBBNum,@DBBNum,x0,TSPAN,JSPAN,rule,options);

%% Transform symbolic solutions to numeric hybrid time domain
maxt = (tsymb(end,2));
mint = (tsymb(1,1));
deltat = tmax; % Number of points to be evaluated in the symbolic function
tvec = eval([mint:abs(maxt-mint)/deltat:maxt]);
% or
% tvec = tnum'; % (slow - same points as the numerical solution)

[t_htd j_htd x_htd] = symhtd2htd(tsymb,jsymb,xsymb,tvec);

%% Ploting solutions symbolic 
figure(1)
plotHarc(t_htd,j_htd,[x_htd(:,1:2),(1+sin(x_htd(:,2)./gamma))*1]);
xlabel('x1')
ylabel('x2')
grid on

figure(2)
plotHarcColor3D(t_htd,j_htd,[t_htd',x_htd(:,2),x_htd(:,1)],j_htd);
grid on
xlabel('time')
ylabel('x_2')
zlabel('x_1')
view(3)

%% Ploting solutions numeric 
figure(3)
plotHarc(tnum,jnum,[xnum(:,1:2),(1+sin(xnum(:,2)./gamma))]);
xlabel('x1')
ylabel('x2')
grid on

figure(4)
plotHarcColor3D(tnum,jnum,[tnum,xnum(:,2),xnum(:,1)],jnum);
grid on
xlabel('time')
ylabel('x_2')
zlabel('x_1')
view(3)
