function h = color_line3HyEQ(x, y, z, c, modificator)
% color_line3 plots a 3-D "line" with c-data as color
% based on:
% 3D colored line plot
% by Georg Stillfried
% http://www.mathworks.com/matlabcentral/fileexchange/23566-3d-colored-line-plot/content/color_line3.m
%
%       h = color_line3HyEQ(x, y, z, c)
%       by default: 'LineStyle','-' and 'Marker','none'
%
%          or
%       h = color_line3HyEQ(x, y, z, c, mark) 
%          or
%       h = color_line3HyEQ(x, y, z, c, 'Property','value'...) 
%             with valid 'Property','value' pairs for a surface object
%
%  in:  x      x-data
%       y      y-data
%       z      z-data
%       c      4th dimension for colouring
%       mark   for scatter plots with no connecting line
%
% out:  h   handle of the surface object


h = surface(...
  'XData',[x(:) x(:)],...
  'YData',[y(:) y(:)],...
  'ZData',[z(:) z(:)],...
  'CData',[c(:) c(:)],...
  'FaceColor','none',...
  'EdgeColor','flat',...
  'Marker','none');
  
if nargin ==5
    switch modificator{1}
        case {'+' 'o' '*' '.' 'x' 'square' 'diamond' 'v' '^' '>' '<' 'pentagram' 'p' 'hexagram' 'h'}
            set(h,'LineStyle',modificator{2},'Marker',modificator{1})
        case {'LineWidth'}
            set(h,'LineWidth',modificator{2})
        otherwise
            error(['Invalid marker: ' modificator{1} modificator{2} '. Use e.g., {*}{--}, {LineWidth}{2}'])
    end

elseif nargin > 5
    set(h,modificator{:})
end